#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

from cthulhu import plugin

import gi
from gi.repository import GObject
import logging

import PluginManagerUi

logger = logging.getLogger(__name__)

class PluginManager(GObject.Object, plugin.Plugin):
    #__gtype_name__ = 'PluginManager'

    object = GObject.Property(type=GObject.Object)
    def __init__(self):
        plugin.Plugin.__init__(self)
        self.pluginManagerUi = None
    @plugin.cthulhu_hookimpl
    def activate(self, plugin=None):
        # Skip if this activation call isn't for us
        if plugin is not None and plugin is not self:
            return
            
        logger.info("Activating PluginManager plugin")
        try:
            if self.app:
                self.registerGestureByString(self.startPluginManagerUi, 'plugin manager', 'kb:cthulhu+e')
            else:
                logger.error("No app reference available")
        except Exception as e:
            logger.error(f"Error activating PluginManager plugin: {e}")
            
    @plugin.cthulhu_hookimpl
    def deactivate(self, plugin=None):
        # Skip if this deactivation call isn't for us
        if plugin is not None and plugin is not self:
            return
            
        logger.info("Deactivating PluginManager plugin")
        # No specific cleanup needed

    def startPluginManagerUi(self, script=None, inputEvent=None):
        self.showUI()
        return True
    def showUI(self):
        API = self.object
        if self.pluginManagerUi == None:
            self.pluginManagerUi = PluginManagerUi.PluginManagerUi(API.app)
            self.pluginManagerUi.setTranslationContext(self.getTranslationContext())
            self.pluginManagerUi.createUI()
            self.pluginManagerUi.run()
            self.pluginManagerUi = None
        else:
            self.pluginManagerUi.present()
