#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

import gi, time
from gi.repository import GObject
import logging

from cthulhu import plugin

logger = logging.getLogger(__name__)

class Time(GObject.Object, plugin.Plugin):
    #__gtype_name__ = 'Time'

    object = GObject.Property(type=GObject.Object)
    def __init__(self):
        plugin.Plugin.__init__(self)
    @plugin.cthulhu_hookimpl
    def activate(self, plugin=None):
        # Skip if this activation call isn't for us
        if plugin is not None and plugin is not self:
            return
            
        logger.info("Activating Time plugin")
        try:
            if self.app:
                signal_manager = self.app.getSignalManager()
                signal_manager.connectSignal("setup-inputeventhandlers-completed", self.setupCompatBinding, "default")
            else:
                logger.error("No app reference available")
        except Exception as e:
            logger.error(f"Error activating Time plugin: {e}")
            
    def setupCompatBinding(self, app):
        try:
            cmdnames = app.getDynamicApiManager().getAPI('Cmdnames')
            inputEventHandlers = app.getDynamicApiManager().getAPI('inputEventHandlers')
            inputEventHandlers['presentTimeHandler'] = app.getAPIHelper().createInputEventHandler(self.presentTime, cmdnames.PRESENT_CURRENT_TIME)
        except Exception as e:
            logger.error(f"Error setting up Time plugin: {e}")
            
    @plugin.cthulhu_hookimpl
    def deactivate(self, plugin=None):
        # Skip if this deactivation call isn't for us
        if plugin is not None and plugin is not self:
            return
            
        logger.info("Deactivating Time plugin")
        try:
            if self.app:
                inputEventHandlers = self.app.getDynamicApiManager().getAPI('inputEventHandlers')
                if 'presentTimeHandler' in inputEventHandlers:
                    del inputEventHandlers['presentTimeHandler']
        except Exception as e:
            logger.error(f"Error deactivating Time plugin: {e}")
        API = self.object
    def presentTime(self, script=None, inputEvent=None):
        """ Presents the current time. """
        API = self.object
        settings_manager = API.app.getDynamicApiManager().getAPI('SettingsManager')
        _settingsManager = settings_manager.getManager()
        timeFormat = _settingsManager.getSetting('presentTimeFormat')
        message = time.strftime(timeFormat, time.localtime())
        API.app.getDynamicApiManager().getAPI('CthulhuState').activeScript.presentMessage(message, resetStyles=False)
        return True
